@@ -25,6 +25,6 @@ package org.crsh.shell.ui;
  */
 enum Pad {
 
-  BRANCH, CONTINUE_BRANCH, LAST_BRANCH, STOP_BRANCH
+  BRANCH, CONTINUE_BRANCH, LAST_BRANCH, STOP_BRANCH, SPACE
 
 }
